"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class SubmissionEventTypeResultTypeEnum(str, Enum):
    r"""Indicates that the routing form submission resulted in a redirect to an event type booking page."""
    EVENT_TYPE = 'event_type'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class SubmissionEventTypeResult:
    r"""Information about the event type Routing Form Submission result."""
    
    type: SubmissionEventTypeResultTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates that the routing form submission resulted in a redirect to an event type booking page."""  
    value: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('value') }})
    r"""A reference to the event type resource."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import errorresponse as shared_errorresponse
from ..shared import organizationmembership as shared_organizationmembership
from ..shared import pagination as shared_pagination
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from typing import Optional


@dataclasses.dataclass
class ListOrganizationMembershipsRequest:
    
    count: Optional[float] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'count', 'style': 'form', 'explode': True }})
    r"""The number of rows to return"""  
    email: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'email', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by email address"""  
    organization: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'organization', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by organization"""  
    page_token: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'page_token', 'style': 'form', 'explode': True }})
    r"""The token to pass to get the next or previous portion of the collection"""  
    user: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'user', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by user"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListOrganizationMembershipsErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListOrganizationMembershipsErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[ListOrganizationMembershipsErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListOrganizationMemberships200ApplicationJSON:
    r"""Service response"""
    
    collection: list[shared_organizationmembership.OrganizationMembership] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})  
    pagination: shared_pagination.Pagination = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination') }})  
    

@dataclasses.dataclass
class ListOrganizationMembershipsResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[ListOrganizationMembershipsErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    error_response1: Optional[shared_errorresponse.ErrorResponse] = dataclasses.field(default=None)
    r"""Caller not authorized to perform this action"""  
    list_organization_memberships_200_application_json_object: Optional[ListOrganizationMemberships200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from marshmallow import fields


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class EventTypeAvailableTime:
    r"""An available meeting time slot for the given event type"""
    
    invitees_remaining: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('invitees_remaining') }})
    r"""Total remaining invitees for this available time. For Group Event Type, more than one invitee can book in this available time. For all other Event Types, only one invitee can book in this available time."""  
    scheduling_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('scheduling_url') }})
    r"""The URL of the user’s scheduling site where invitees book this event type"""  
    start_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('start_time'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the event was scheduled to start in UTC time"""  
    status: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates that the open time slot is \\"available\\" """  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class LegacyCalendarEventKindEnum(str, Enum):
    r"""Indicates the calendar provider the event belongs to."""
    EXCHANGE = 'exchange'
    GOOGLE = 'google'
    ICLOUD = 'icloud'
    OUTLOOK = 'outlook'
    OUTLOOK_DESKTOP = 'outlook_desktop'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class LegacyCalendarEvent:
    r"""Information about the calendar event from the calendar provider."""
    
    external_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('external_id') }})
    r"""the id provided from the calendar provider for this calendar event."""  
    kind: LegacyCalendarEventKindEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('kind') }})
    r"""Indicates the calendar provider the event belongs to."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations, shared
from typing import Any, Optional

class DataCompliance:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def create_deletion_event(self, request: operations.PostDataComplianceDeletionEventsRequestBody) -> operations.PostDataComplianceDeletionEventsResponse:
        r"""Delete Scheduled Event Data
        <!-- theme: info -->
          > This endpoint requires an <strong>Enterprise</strong> subscription.
        
        To submit a request to remove scheduled events data within a time range for your organization, use this endpoint. Requests for data deletion can take up to 7 days to complete.
        
        Time range can be no greater than 24 months and must occur in the past.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/data_compliance/deletion/events'
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        
        client = self._security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostDataComplianceDeletionEventsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 202:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[dict[str, Any]])
                res.post_data_compliance_deletion_events_202_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostDataComplianceDeletionEventsErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response1 = out

        return res

    def delete_invitee_data(self, request: operations.PostDataComplianceDeletionInviteesRequestBody) -> operations.PostDataComplianceDeletionInviteesResponse:
        r"""Delete Invitee Data
        <!-- theme: info -->
          > This endpoint requires an <strong>Enterprise</strong> subscription.
        
        To submit a request to remove invitee data from all previously booked events in your organization, use this endpoint. Requests for data deletion can take up to 7 days to complete.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/data_compliance/deletion/invitees'
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        
        client = self._security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostDataComplianceDeletionInviteesResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 202:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[dict[str, Any]])
                res.post_data_compliance_deletion_invitees_202_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostDataComplianceDeletionInviteesErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response1 = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import webhooksubscription as shared_webhooksubscription
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional

class PostUsersUUIDWebhooksRequestBodyEventsEnum(str, Enum):
    INVITEE_CANCELED = 'invitee.canceled'
    INVITEE_CREATED = 'invitee.created'
    ROUTING_FORM_SUBMISSION_CREATED = 'routing_form_submission.created'

class PostUsersUUIDWebhooksRequestBodyScopeEnum(str, Enum):
    r"""Indicates if the webhook subscription scope will be \\"organization\\" or \\"user\\" """
    ORGANIZATION = 'organization'
    USER = 'user'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostUsersUUIDWebhooksRequestBody:
    
    events: list[PostUsersUUIDWebhooksRequestBodyEventsEnum] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('events') }})
    r"""List of user events to subscribe to."""  
    organization: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organization') }})
    r"""The unique reference to the organization that the webhook will be tied to."""  
    scope: PostUsersUUIDWebhooksRequestBodyScopeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('scope') }})
    r"""Indicates if the webhook subscription scope will be \\"organization\\" or \\"user\\" """  
    url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('url') }})
    r"""The URL where you want to receive POST requests for events you are subscribed to."""  
    signing_key: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('signing_key'), 'exclude': lambda f: f is None }})
    r"""Optional secret key shared between your application and Calendly. See https://developer.calendly.com/api-docs/ZG9jOjM2MzE2MDM4-webhook-signatures for additional information."""  
    user: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user'), 'exclude': lambda f: f is None }})
    r"""The unique reference to the user that the webhook will be tied to."""  
    
class PostUsersUUIDWebhooks403ApplicationJSONMessageEnum(str, Enum):
    PLEASE_UPGRADE_YOUR_CALENDLY_ACCOUNT_TO_PROFESSIONAL = 'Please upgrade your Calendly account to Professional'
    YOU_DO_NOT_HAVE_PERMISSION_TO_ACCESS_THIS_RESOURCE_ = 'You do not have permission to access this resource.'
    YOU_DO_NOT_HAVE_PERMISSION = 'You do not have permission'

class PostUsersUUIDWebhooks403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostUsersUUIDWebhooks403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[PostUsersUUIDWebhooks403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[PostUsersUUIDWebhooks403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostUsersUUIDWebhooksErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostUsersUUIDWebhooksErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[PostUsersUUIDWebhooksErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostUsersUUIDWebhooks201ApplicationJSON:
    r"""Created"""
    
    resource: shared_webhooksubscription.WebhookSubscription = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resource') }})
    r"""Webhook Subscription Object"""  
    

@dataclasses.dataclass
class PostUsersUUIDWebhooksResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[PostUsersUUIDWebhooksErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    post_users_uuid_webhooks_201_application_json_object: Optional[PostUsersUUIDWebhooks201ApplicationJSON] = dataclasses.field(default=None)
    r"""Created"""  
    post_users_uuid_webhooks_403_application_json_object: Optional[PostUsersUUIDWebhooks403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import errorresponse as shared_errorresponse
from ..shared import organizationinvitation as shared_organizationinvitation
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostOrganizationsUUIDInvitationsRequestBody:
    
    email: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email') }})
    r"""The email of the user being invited"""  
    

@dataclasses.dataclass
class PostOrganizationsUUIDInvitationsRequest:
    
    request_body: PostOrganizationsUUIDInvitationsRequestBody = dataclasses.field(metadata={'request': { 'media_type': 'application/json' }})  
    uuid: str = dataclasses.field(metadata={'path_param': { 'field_name': 'uuid', 'style': 'simple', 'explode': False }})
    r"""The organization's unique identifier"""  
    
class PostOrganizationsUUIDInvitations403ApplicationJSONMessageEnum(str, Enum):
    YOU_ALREADY_SENT_ALL_THE_INVITATIONS_YOU_RE_ALLOTTED_BASED_UPON_THE_NUMBER_OF_SEATS_PURCHASED_WITH_YOUR_ACCOUNT_PLEASE_PURCHASE_MORE_SEATS_TO_SEND_MORE_INVITATIONS_ = 'You already sent all the invitations you\'re allotted based upon the number of seats purchased with your account. Please purchase more seats to send more invitations.'
    YOU_ALREADY_SENT_ALL_THE_INVITATIONS_ALLOTTED_TO_YOU_WITH_A_TRIAL_ACCOUNT_ = 'You already sent all the invitations allotted to you with a trial account.'
    YOU_DO_NOT_HAVE_PERMISSION = 'You do not have permission'
    YOU_CANNOT_PERFORM_THIS_ACTION_FOR_AN_ORGANIZATION_WITH_SCIM_ENABLED_ = 'You cannot perform this action for an organization with SCIM enabled.'

class PostOrganizationsUUIDInvitations403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostOrganizationsUUIDInvitations403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[PostOrganizationsUUIDInvitations403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[PostOrganizationsUUIDInvitations403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostOrganizationsUUIDInvitationsErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostOrganizationsUUIDInvitationsErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[PostOrganizationsUUIDInvitationsErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostOrganizationsUUIDInvitations201ApplicationJSON:
    r"""Created"""
    
    resource: shared_organizationinvitation.OrganizationInvitation = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resource') }})
    r"""Organization Invitation object"""  
    

@dataclasses.dataclass
class PostOrganizationsUUIDInvitationsResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response1: Optional[PostOrganizationsUUIDInvitationsErrorResponse] = dataclasses.field(default=None)
    r"""Cannot authenticate caller"""  
    error_response: Optional[shared_errorresponse.ErrorResponse] = dataclasses.field(default=None)
    r"""Bad Request"""  
    post_organizations_uuid_invitations_201_application_json_object: Optional[PostOrganizationsUUIDInvitations201ApplicationJSON] = dataclasses.field(default=None)
    r"""Created"""  
    post_organizations_uuid_invitations_403_application_json_object: Optional[PostOrganizationsUUIDInvitations403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields

class WebhookSubscriptionEventsEnum(str, Enum):
    INVITEE_CREATED = 'invitee.created'
    INVITEE_CANCELED = 'invitee.canceled'
    ROUTING_FORM_SUBMISSION_CREATED = 'routing_form_submission.created'

class WebhookSubscriptionScopeEnum(str, Enum):
    r"""The scope of the webhook subscription"""
    USER = 'user'
    ORGANIZATION = 'organization'

class WebhookSubscriptionStateEnum(str, Enum):
    r"""Indicates if the webhook subscription is \\"active\\" or \\"disabled\\" """
    ACTIVE = 'active'
    DISABLED = 'disabled'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class WebhookSubscription:
    r"""Webhook Subscription Object"""
    
    callback_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('callback_url') }})
    r"""The callback URL to use when the event is triggered"""  
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the webhook subscription was created (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    creator: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('creator') }})
    r"""The URI of the user who created the webhook subscription"""  
    events: list[WebhookSubscriptionEventsEnum] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('events') }})
    r"""A list of events to which the webhook is subscribed"""  
    organization: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organization') }})
    r"""The URI of the organization that's associated with the webhook subscription"""  
    retry_started_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('retry_started_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The date and time the webhook subscription is retried"""  
    scope: WebhookSubscriptionScopeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('scope') }})
    r"""The scope of the webhook subscription"""  
    state: WebhookSubscriptionStateEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('state') }})
    r"""Indicates if the webhook subscription is \\"active\\" or \\"disabled\\" """  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the webhook subscription was last updated (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the webhook"""  
    user: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user') }})
    r"""The URI of the user that's associated with the webhook subscription"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations, shared
from typing import Optional

class Availability:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def get(self, request: operations.GetUserAvailabilitySchedulesUUIDRequest) -> operations.GetUserAvailabilitySchedulesUUIDResponse:
        r"""Get User Availability Schedule
        This will return the availability schedule of the given UUID.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetUserAvailabilitySchedulesUUIDRequest, base_url, '/user_availability_schedules/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetUserAvailabilitySchedulesUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserAvailabilitySchedulesUUID200ApplicationJSON])
                res.get_user_availability_schedules_uuid_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserAvailabilitySchedulesUUIDErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserAvailabilitySchedulesUUID403ApplicationJSON])
                res.get_user_availability_schedules_uuid_403_application_json_object = out
        elif http_res.status_code == 500:
            pass

        return res

    def get_availability(self, request: operations.GetUserAvailabilitySchedulesRequest) -> operations.GetUserAvailabilitySchedulesResponse:
        r"""List User Availability Schedules
        Returns the availability schedules of the given user.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/user_availability_schedules'
        
        query_params = utils.get_query_params(operations.GetUserAvailabilitySchedulesRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetUserAvailabilitySchedulesResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserAvailabilitySchedules200ApplicationJSON])
                res.get_user_availability_schedules_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserAvailabilitySchedulesErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserAvailabilitySchedules403ApplicationJSON])
                res.get_user_availability_schedules_403_application_json_object = out

        return res

    def get_busy_times(self, request: operations.GetUserBusyTimesRequest) -> operations.GetUserBusyTimesResponse:
        r"""List User Busy Times
        Returns an ascending list of user internal and external scheduled events within a specified date range.
        
        Date range can be no greater than 1 week (7 days).
        
        **NOTE:**
        * This endpoint does not support traditional keyset pagination.
        * External events will only be returned for calendars that have \"Check for conflicts\" configured.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/user_busy_times'
        
        query_params = utils.get_query_params(operations.GetUserBusyTimesRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetUserBusyTimesResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserBusyTimes200ApplicationJSON])
                res.get_user_busy_times_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserBusyTimesErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetUserBusyTimes403ApplicationJSON])
                res.get_user_busy_times_403_application_json_object = out
        elif http_res.status_code == 424:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response1 = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class OutboundCallTypeEnum(str, Enum):
    r"""Indicates that the event host (publisher) will call the invitee"""
    OUTBOUND_CALL = 'outbound_call'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class OutboundCall:
    r"""Meeting publisher will call the Invitee"""
    
    location: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The phone number the event host (publisher) will use to call the invitee"""  
    type: OutboundCallTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""Indicates that the event host (publisher) will call the invitee"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields

class OrganizationMembershipRoleEnum(str, Enum):
    r"""The user's role in the organization"""
    USER = 'user'
    ADMIN = 'admin'
    OWNER = 'owner'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class OrganizationMembershipUser:
    r"""Information about the user."""
    
    avatar_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('avatar_url') }})
    r"""The URL of the user's avatar (image)"""  
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the user's record was created (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    email: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('email') }})
    r"""The user's email address"""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The user's name (human-readable format)"""  
    scheduling_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('scheduling_url') }})
    r"""The URL of the user's Calendly landing page (that lists all the user's event types)"""  
    slug: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('slug') }})
    r"""The portion of URL for the user's scheduling page (where invitees book sessions), rendered in a human-readable format"""  
    timezone: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('timezone') }})
    r"""The time zone to use when presenting time to the user"""  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the user's record was last updated (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the user"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class OrganizationMembership:
    
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the membership record was created (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    organization: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organization') }})
    r"""A unique reference to the organization"""  
    role: OrganizationMembershipRoleEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('role') }})
    r"""The user's role in the organization"""  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the membership record was last updated (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the membership"""  
    user: OrganizationMembershipUser = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user') }})
    r"""Information about the user."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations, shared
from typing import Optional

class ScheduledEvents:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def cancel(self, request: operations.PostScheduledEventsUUIDCancellationRequest) -> operations.PostScheduledEventsUUIDCancellationResponse:
        r"""Cancel Event
        Cancels specified event.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.PostScheduledEventsUUIDCancellationRequest, base_url, '/scheduled_events/{uuid}/cancellation', request)
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request_body", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        
        client = self._security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostScheduledEventsUUIDCancellationResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 201:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostScheduledEventsUUIDCancellation201ApplicationJSON])
                res.post_scheduled_events_uuid_cancellation_201_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostScheduledEventsUUIDCancellationErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostScheduledEventsUUIDCancellation403ApplicationJSON])
                res.post_scheduled_events_uuid_cancellation_403_application_json_object = out

        return res

    def create_no_show(self, request: operations.PostInviteeNoShowRequestBody) -> operations.PostInviteeNoShowResponse:
        r"""Create Invitee No Show
        Marks an Invitee as a No Show.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/invitee_no_shows'
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        
        client = self._security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostInviteeNoShowResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 201:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostInviteeNoShow201ApplicationJSON])
                res.post_invitee_no_show_201_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostInviteeNoShowErrorResponse])
                res.error_response = out

        return res

    def get_event_by_uuid(self, request: operations.GetScheduledEventsUUIDRequest) -> operations.GetScheduledEventsUUIDResponse:
        r"""Get Event
        Returns information about a specified Event.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetScheduledEventsUUIDRequest, base_url, '/scheduled_events/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetScheduledEventsUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetScheduledEventsUUID200ApplicationJSON])
                res.get_scheduled_events_uuid_200_application_json_object = out
        elif http_res.status_code in [401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetScheduledEventsUUIDErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetScheduledEventsUUID403ApplicationJSON])
                res.get_scheduled_events_uuid_403_application_json_object = out

        return res

    def get_invitees(self, request: operations.GetInviteesRequest) -> operations.GetInviteesResponse:
        r"""List Event Invitees
        Returns a list of Invitees for an event.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetInviteesRequest, base_url, '/scheduled_events/{uuid}/invitees', request)
        
        query_params = utils.get_query_params(operations.GetInviteesRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetInviteesResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetInvitees200ApplicationJSON])
                res.get_invitees_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetInviteesErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetInvitees403ApplicationJSON])
                res.get_invitees_403_application_json_object = out

        return res

    def get_invitees_by_uuid(self, request: operations.GetScheduledEventsEventUUIDInviteesInviteeUUIDRequest) -> operations.GetScheduledEventsEventUUIDInviteesInviteeUUIDResponse:
        r"""Get Event Invitee
        Returns information about a specified Invitee (person invited to an event).
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetScheduledEventsEventUUIDInviteesInviteeUUIDRequest, base_url, '/scheduled_events/{event_uuid}/invitees/{invitee_uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetScheduledEventsEventUUIDInviteesInviteeUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetScheduledEventsEventUUIDInviteesInviteeUUID200ApplicationJSON])
                res.get_scheduled_events_event_uuid_invitees_invitee_uuid_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetScheduledEventsEventUUIDInviteesInviteeUUIDErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response1 = out

        return res

    def get_no_show(self, request: operations.GetInviteeNoShowRequest) -> operations.GetInviteeNoShowResponse:
        r"""Get Invitee No Show
        Returns information about a specified Invitee No Show.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetInviteeNoShowRequest, base_url, '/invitee_no_shows/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetInviteeNoShowResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetInviteeNoShow200ApplicationJSON])
                res.get_invitee_no_show_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetInviteeNoShowErrorResponse])
                res.error_response = out

        return res

    def list(self, request: operations.ListScheduledEventsRequest) -> operations.ListScheduledEventsResponse:
        r"""List Events
        Returns a list of  Events.
        
        * Pass `organization` parameter to return events for that organization (requires admin/owner privilege)
        * Pass `user` parameter to return events for a specific User
        
        **NOTES:**
        * If you are the admin/owner of the organization, you can use both `organization` and `user` to get a list of events for a specific user within your organization.
        
        * `user` can only be used alone when requesting your own personal events. This will return your events within any organization that you are currently in or were a part of in the past.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/scheduled_events'
        
        query_params = utils.get_query_params(operations.ListScheduledEventsRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ListScheduledEventsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ScheduledEventsResponse])
                res.scheduled_events_response = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListScheduledEventsErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListScheduledEvents403ApplicationJSON])
                res.list_scheduled_events_403_application_json_object = out

        return res

    def unmark_no_show(self, request: operations.DeleteInviteeNoShowRequest) -> operations.DeleteInviteeNoShowResponse:
        r"""Delete Invitee No Show
        Undoes marking an Invitee as a No Show.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.DeleteInviteeNoShowRequest, base_url, '/invitee_no_shows/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('DELETE', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.DeleteInviteeNoShowResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 204:
            pass
        elif http_res.status_code in [401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.DeleteInviteeNoShowErrorResponse])
                res.error_response = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
import requests as requests_http
from ..shared import errorresponse as shared_errorresponse
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from marshmallow import fields
from typing import Any, Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostDataComplianceDeletionEventsRequestBody:
    r"""The start and end times that delineate the time range for scheduled events data deletion."""
    
    end_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('end_time'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The scheduled events UTC timestamp at which data deletion should end."""  
    start_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('start_time'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The scheduled events UTC timestamp at which data deletion should begin."""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostDataComplianceDeletionEventsErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostDataComplianceDeletionEventsErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[PostDataComplianceDeletionEventsErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclasses.dataclass
class PostDataComplianceDeletionEventsResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[PostDataComplianceDeletionEventsErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    error_response1: Optional[shared_errorresponse.ErrorResponse] = dataclasses.field(default=None)
    r"""Forbidden"""  
    post_data_compliance_deletion_events_202_application_json_object: Optional[dict[str, Any]] = dataclasses.field(default=None)
    r"""Accepted"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .actor import *
from .availabilityrule import *
from .availabilityschedule import *
from .cancellation import *
from .customlocation import *
from .entry import *
from .errorresponse import *
from .event import *
from .eventtype import *
from .eventtypeavailabletime import *
from .eventtypecustomquestion import *
from .googleconference import *
from .gotomeetingconference import *
from .guest import *
from .inboundcall import *
from .inpersonmeeting import *
from .invitee import *
from .inviteenoshow import *
from .inviteequestionandanswer import *
from .inviteespecifiedlocation import *
from .inviteetracking import *
from .legacycalendarevent import *
from .microsoftteamsconference import *
from .organizationinvitation import *
from .organizationmembership import *
from .outboundcall import *
from .pagination import *
from .profile import *
from .question import *
from .routingform import *
from .routingformsubmission import *
from .scheduledeventsresponse import *
from .security import *
from .share import *
from .submissioncustommessageresult import *
from .submissioneventtyperesult import *
from .submissionexternalurlresult import *
from .submissionquestionandanswer import *
from .submissiontracking import *
from .user import *
from .userbusytime import *
from .webexconference import *
from .webhooksubscription import *
from .zoomconference import *

__all__ = ["Actor","ActorGroup","ActorOrganization","AvailabilityRule","AvailabilityRuleIntervals","AvailabilityRuleTypeEnum","AvailabilityRuleWdayEnum","AvailabilitySchedule","Cancellation","CancellationCancelerTypeEnum","CustomLocation","CustomLocationTypeEnum","Entry","ErrorResponse","ErrorResponseDetails","Event","EventEventMemberships","EventInviteesCounter","EventStatusEnum","EventType","EventTypeAvailableTime","EventTypeBookingMethodEnum","EventTypeCustomQuestion","EventTypeCustomQuestionTypeEnum","EventTypeKindDescriptionEnum","EventTypeKindEnum","EventTypePoolingTypeEnum","EventTypeTypeEnum","GoogleConference","GoogleConferenceStatusEnum","GoogleConferenceTypeEnum","GotoMeetingConference","GotoMeetingConferenceData","GotoMeetingConferenceStatusEnum","GotoMeetingConferenceTypeEnum","Guest","InPersonMeeting","InPersonMeetingTypeEnum","InboundCall","InboundCallTypeEnum","Invitee","InviteeNoShow","InviteeNoShow1","InviteePayment","InviteePaymentCurrencyEnum","InviteePaymentProviderEnum","InviteeQuestionAndAnswer","InviteeReconfirmation","InviteeSpecifiedLocation","InviteeSpecifiedLocationTypeEnum","InviteeStatusEnum","InviteeTracking","LegacyCalendarEvent","LegacyCalendarEventKindEnum","MicrosoftTeamsConference","MicrosoftTeamsConferenceData","MicrosoftTeamsConferenceDataAudioConferencing","MicrosoftTeamsConferenceStatusEnum","MicrosoftTeamsConferenceTypeEnum","OrganizationInvitation","OrganizationInvitationStatusEnum","OrganizationMembership","OrganizationMembershipRoleEnum","OrganizationMembershipUser","OutboundCall","OutboundCallTypeEnum","Pagination","Profile","ProfileTypeEnum","Question","QuestionTypeEnum","RoutingForm","RoutingFormStatusEnum","RoutingFormSubmission","RoutingFormSubmissionSubmitterTypeEnum","ScheduledEventsResponse","Security","Share","ShareSchedulingLinks","ShareSchedulingLinksOwnerTypeEnum","ShareShareOverride","ShareShareOverrideAvailabilityRule","ShareShareOverrideAvailabilityRuleRules","ShareShareOverrideAvailabilityRuleRulesIntervals","ShareShareOverrideAvailabilityRuleRulesTypeEnum","ShareShareOverrideAvailabilityRuleRulesWdayEnum","ShareShareOverrideLocationConfigurations","ShareShareOverrideLocationConfigurationsKindEnum","ShareShareOverridePeriodTypeEnum","SubmissionCustomMessageResult","SubmissionCustomMessageResultTypeEnum","SubmissionCustomMessageResultValue","SubmissionEventTypeResult","SubmissionEventTypeResultTypeEnum","SubmissionExternalURLResult","SubmissionExternalURLResultTypeEnum","SubmissionQuestionAndAnswer","SubmissionTracking","User","UserBusyTime","UserBusyTimeEvent","UserBusyTimeTypeEnum","WebExConference","WebExConferenceData","WebExConferenceDataTelephony","WebExConferenceDataTelephonyCallInNumbers","WebExConferenceStatusEnum","WebExConferenceTypeEnum","WebhookSubscription","WebhookSubscriptionEventsEnum","WebhookSubscriptionScopeEnum","WebhookSubscriptionStateEnum","ZoomConference","ZoomConferenceData","ZoomConferenceDataExtra","ZoomConferenceDataSettings","ZoomConferenceDataSettingsGlobalDialInNumbers","ZoomConferenceStatusEnum","ZoomConferenceTypeEnum"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import cancellation as shared_cancellation
from ..shared import guest as shared_guest
from ..shared import legacycalendarevent as shared_legacycalendarevent
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields
from typing import Any, Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class EventEventMemberships:
    
    user: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('user') }})
    r"""Canonical reference (unique identifier) for the user"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class EventInviteesCounter:
    
    active: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('active') }})
    r"""Total invitees for an event that have not canceled"""  
    limit: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('limit') }})
    r"""Maximum number of active invitees that can book the event"""  
    total: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('total') }})
    r"""Total invitees for an event, including invitees that have canceled"""  
    
class EventStatusEnum(str, Enum):
    r"""Indicates if the event is \\"active\\" or \\"canceled\\" """
    ACTIVE = 'active'
    CANCELED = 'canceled'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Event:
    r"""Information about a scheduled meeting"""
    
    calendar_event: shared_legacycalendarevent.LegacyCalendarEvent = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('calendar_event') }})
    r"""Information about the calendar event from the calendar provider."""  
    created_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('created_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the event was created (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    end_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('end_time'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the event was scheduled to end in UTC time (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    event_guests: list[shared_guest.Guest] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('event_guests') }})
    r"""Additional people added to an event by an invitee"""  
    event_memberships: list[EventEventMemberships] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('event_memberships') }})
    r"""Event membership list"""  
    event_type: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('event_type') }})
    r"""The event type associated with this event"""  
    invitees_counter: EventInviteesCounter = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('invitees_counter') }})  
    location: Any = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('location') }})
    r"""The polymorphic base type for an event location that Calendly supports"""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The event name"""  
    start_time: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('start_time'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment the event was scheduled to start in UTC time (e.g. \\"2020-01-02T03:04:05.678123Z\\")."""  
    status: EventStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates if the event is \\"active\\" or \\"canceled\\" """  
    updated_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('updated_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The moment when the event was last updated (e.g. \\"2020-01-02T03:04:05.678123Z\\")"""  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})
    r"""Canonical reference (unique identifier) for the resource"""  
    cancellation: Optional[shared_cancellation.Cancellation] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('cancellation'), 'exclude': lambda f: f is None }})
    r"""Provides data pertaining to the cancellation of the Event"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class SubmissionQuestionAndAnswer:
    r"""All Routing Form Submission questions with answers."""
    
    question: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('question') }})
    r"""Question name (in human-readable format)."""  
    question_uuid: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('question_uuid') }})
    r"""Unique identifier for the routing form question."""  
    answer: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('answer'), 'exclude': lambda f: f is None }})
    r"""Answer provided by the respondent when the form was submitted."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ActorGroup:
    r"""User group information about the actor"""
    
    name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name'), 'exclude': lambda f: f is None }})
    r"""Name of the user group"""  
    role: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('role'), 'exclude': lambda f: f is None }})
    r"""The actor's role in the user group"""  
    uri: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri'), 'exclude': lambda f: f is None }})
    r"""Canonical reference (unique identifier) for the user group"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ActorOrganization:
    
    role: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('role'), 'exclude': lambda f: f is None }})
    r"""The actors' role in the organization"""  
    uri: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri'), 'exclude': lambda f: f is None }})
    r"""Canonical reference (unique identifier) for the organization"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Actor:
    r"""The Calendly actor that took the action creating the activity log entry
    
    Specific actors:
    
    <details>
    <summary>Calendly System</summary>
    
    Used when an action is performed by the Calendly system and not triggered directly by a user interaction.
    
    Example:
    ```json
    {
        \"display_name\": \"Calendly System\",
        \"type\": \"System\"
    }
    ```
    
    </details>
    
    <br />
    
    <details>
    <summary>Calendly Support</summary>
    Used when an action is performed by Calendly support.
    
    Example:
    ```json
    {
      \"display_name\": \"Calendly Support\",
      \"organization\": {
        \"uri\": \"https://api.calendly.com/organizations/AAAAAAAAAAAAAAAA\"
      },
      \"type\": \"User\",
      \"uri\": \"https://api.calendly.com/users/AAAAAAAAAAAAAAAA\"
    }
    ```
    </details>
    """
    
    type: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The type of actor"""  
    alternative_identifier: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('alternative_identifier'), 'exclude': lambda f: f is None }})
    r"""Username of the actor"""  
    display_name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('display_name'), 'exclude': lambda f: f is None }})
    r"""The user's name (human-readable format)"""  
    group: Optional[ActorGroup] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('group'), 'exclude': lambda f: f is None }})
    r"""User group information about the actor"""  
    organization: Optional[ActorOrganization] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organization'), 'exclude': lambda f: f is None }})  
    uri: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri'), 'exclude': lambda f: f is None }})
    r"""Canonical reference (unique identifier) for the user"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
import requests as requests_http
from ..shared import entry as shared_entry
from ..shared import pagination as shared_pagination
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from enum import Enum
from marshmallow import fields
from typing import Optional

class ListActivityLogSortEnum(str, Enum):
    ACTION_ASC = 'action:asc'
    ACTION_DESC = 'action:desc'
    ACTOR_DISPLAY_NAME_ASC = 'actor.display_name:asc'
    ACTOR_DISPLAY_NAME_DESC = 'actor.display_name:desc'
    ACTOR_URI_ASC = 'actor.uri:asc'
    ACTOR_URI_DESC = 'actor.uri:desc'
    NAMESPACE_ASC = 'namespace:asc'
    NAMESPACE_DESC = 'namespace:desc'
    OCCURRED_AT_ASC = 'occurred_at:asc'
    OCCURRED_AT_DESC = 'occurred_at:desc'


@dataclasses.dataclass
class ListActivityLogRequest:
    
    organization: str = dataclasses.field(metadata={'query_param': { 'field_name': 'organization', 'style': 'form', 'explode': True }})
    r"""Return activity log entries from the organization associated with this URI"""  
    action: Optional[list[str]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'action', 'style': 'form', 'explode': False }})
    r"""The action(s) associated with the entries"""  
    actor: Optional[list[str]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'actor', 'style': 'form', 'explode': False }})
    r"""Return entries from the user(s) associated with the provided URIs"""  
    count: Optional[int] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'count', 'style': 'form', 'explode': True }})
    r"""The number of rows to return"""  
    max_occurred_at: Optional[datetime] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'max_occurred_at', 'style': 'form', 'explode': True }})
    r"""Include entries that occurred prior to this time (sample time format: \\"2020-01-02T03:04:05.678Z\\"). This time should use the UTC timezone."""  
    min_occurred_at: Optional[datetime] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'min_occurred_at', 'style': 'form', 'explode': True }})
    r"""Include entries that occurred after this time (sample time format: \\"2020-01-02T03:04:05.678Z\\"). This time should use the UTC timezone."""  
    namespace: Optional[list[str]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'namespace', 'style': 'form', 'explode': False }})
    r"""The categories of the entries"""  
    page_token: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'page_token', 'style': 'form', 'explode': True }})
    r"""The token to pass to get the next portion of the collection"""  
    search_term: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'search_term', 'style': 'form', 'explode': True }})
    r"""Filters entries based on the search term.
    
    Supported operators:
      - `|` - to allow filtering by one term or another. Example: `this | that`
      - `+` - to allow filtering by one term and another. Example: `this + that`
      - `\"` - to allow filtering by an exact search term. Example: `\"email@website.com\"`
      - `-` - to omit specific terms from results. Example: `Added -User`
      - `()` - to allow specifying precedence during a search. Example: `(this + that) OR (person + place)`
      - `*` - to allow prefix searching. Example `*@other-website.com`
    """  
    sort: Optional[list[ListActivityLogSortEnum]] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sort', 'style': 'form', 'explode': False }})
    r"""Order results by the specified field and direction. List of {field}:{direction} values."""  
    
class ListActivityLog403ApplicationJSONMessageEnum(str, Enum):
    PLEASE_UPGRADE_YOUR_CALENDLY_ACCOUNT_TO_ENTERPRISE_ = 'Please upgrade your Calendly account to Enterprise.'
    YOU_DO_NOT_HAVE_PERMISSION_TO_ACCESS_THIS_RESOURCE_ = 'You do not have permission to access this resource.'

class ListActivityLog403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListActivityLog403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[ListActivityLog403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[ListActivityLog403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListActivityLogErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListActivityLogErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[ListActivityLogErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListActivityLog200ApplicationJSON:
    r"""Activity log response"""
    
    collection: list[shared_entry.Entry] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})
    r"""The set of activity log entries matching the criteria"""  
    exceeds_max_total_count: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('exceeds_max_total_count') }})
    r"""If there are more search results than the total_count field indicates, pagination will continue to return results past the total_count field value."""  
    pagination: shared_pagination.Pagination = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination') }})  
    total_count: int = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('total_count') }})
    r"""Total number of records based on search criteria"""  
    last_event_time: Optional[datetime] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('last_event_time'), 'encoder': utils.datetimeisoformat(True), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso'), 'exclude': lambda f: f is None }})
    r"""The date and time of the newest entry (format: \\"2020-01-02T03:04:05.678Z\\") in the collection array."""  
    

@dataclasses.dataclass
class ListActivityLogResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[ListActivityLogErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    list_activity_log_200_application_json_object: Optional[ListActivityLog200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    list_activity_log_403_application_json_object: Optional[ListActivityLog403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations, shared
from typing import Optional

class Organizations:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def delete_memberships(self, request: operations.DeleteOrganizationsUUIDMembershipsRequest) -> operations.DeleteOrganizationsUUIDMembershipsResponse:
        r"""Remove User from Organization
        Removes a user from an organization.
        
        Notes:
        
        * To remove users, the caller must have admin rights for the organization
        
        * An organization owner can’t be removed
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.DeleteOrganizationsUUIDMembershipsRequest, base_url, '/organization_memberships/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('DELETE', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.DeleteOrganizationsUUIDMembershipsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 204:
            pass
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.DeleteOrganizationsUUIDMembershipsErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response1 = out

        return res

    def get_invitations(self, request: operations.GetOrganizationsOrgUUIDInvitationsUUIDRequest) -> operations.GetOrganizationsOrgUUIDInvitationsUUIDResponse:
        r"""Get Organization Invitation
        Returns an Organization Invitation that was sent to the organization's members.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetOrganizationsOrgUUIDInvitationsUUIDRequest, base_url, '/organizations/{org_uuid}/invitations/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetOrganizationsOrgUUIDInvitationsUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetOrganizationsOrgUUIDInvitationsUUID200ApplicationJSON])
                res.get_organizations_org_uuid_invitations_uuid_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetOrganizationsOrgUUIDInvitationsUUIDErrorResponse])
                res.error_response = out

        return res

    def invite_user(self, request: operations.PostOrganizationsUUIDInvitationsRequest) -> operations.PostOrganizationsUUIDInvitationsResponse:
        r"""Invite User to Organization
        Invites a user to an organization.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.PostOrganizationsUUIDInvitationsRequest, base_url, '/organizations/{uuid}/invitations', request)
        
        headers = {}
        req_content_type, data, form = utils.serialize_request_body(request, "request_body", 'json')
        if req_content_type not in ('multipart/form-data', 'multipart/mixed'):
            headers['content-type'] = req_content_type
        if data is None and form is None:
            raise Exception('request body is required')
        
        client = self._security_client
        
        http_res = client.request('POST', url, data=data, files=form, headers=headers)
        content_type = http_res.headers.get('Content-Type')

        res = operations.PostOrganizationsUUIDInvitationsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 201:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostOrganizationsUUIDInvitations201ApplicationJSON])
                res.post_organizations_uuid_invitations_201_application_json_object = out
        elif http_res.status_code == 400:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response = out
        elif http_res.status_code in [401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostOrganizationsUUIDInvitationsErrorResponse])
                res.error_response1 = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.PostOrganizationsUUIDInvitations403ApplicationJSON])
                res.post_organizations_uuid_invitations_403_application_json_object = out

        return res

    def list_invitations(self, request: operations.GetOrganizationsUUIDInvitationsRequest) -> operations.GetOrganizationsUUIDInvitationsResponse:
        r"""List Organization Invitations
        Returns a list of Organization Invitations that were sent to the organization's members.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetOrganizationsUUIDInvitationsRequest, base_url, '/organizations/{uuid}/invitations', request)
        
        query_params = utils.get_query_params(operations.GetOrganizationsUUIDInvitationsRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetOrganizationsUUIDInvitationsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetOrganizationsUUIDInvitations200ApplicationJSON])
                res.get_organizations_uuid_invitations_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetOrganizationsUUIDInvitationsErrorResponse])
                res.error_response = out

        return res

    def list_memberships(self, request: operations.ListOrganizationMembershipsRequest) -> operations.ListOrganizationMembershipsResponse:
        r"""List Organization Memberships
        Use this to list the Organization Memberships for all users belonging to an organization, use:
        
        * `user` to look up a user's membership in an organization
        
        * `organization` to look up all users that belong to the organization
        
        This endpoint can also be used to retrieve your organization URI.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/organization_memberships'
        
        query_params = utils.get_query_params(operations.ListOrganizationMembershipsRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ListOrganizationMembershipsResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListOrganizationMemberships200ApplicationJSON])
                res.list_organization_memberships_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListOrganizationMembershipsErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response1 = out

        return res

    def revoke_invite(self, request: operations.RevokeUsersOrganizationInvitationRequest) -> operations.RevokeUsersOrganizationInvitationResponse:
        r"""Revoke User's Organization Invitation
        Use this to revoke an Organization Invitation to an organization. Once revoked, the invitation link that was sent to the invitee is no longer valid.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.RevokeUsersOrganizationInvitationRequest, base_url, '/organizations/{org_uuid}/invitations/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('DELETE', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.RevokeUsersOrganizationInvitationResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 204:
            pass
        elif http_res.status_code == 400:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[shared.ErrorResponse])
                res.error_response = out
        elif http_res.status_code in [401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.RevokeUsersOrganizationInvitationErrorResponse])
                res.error_response1 = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.RevokeUsersOrganizationInvitation403ApplicationJSON])
                res.revoke_users_organization_invitation_403_application_json_object = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import availabilityschedule as shared_availabilityschedule
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclasses.dataclass
class GetUserAvailabilitySchedulesRequest:
    
    user: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'user', 'style': 'form', 'explode': True }})
    r"""A URI reference to a user"""  
    
class GetUserAvailabilitySchedules403ApplicationJSONMessageEnum(str, Enum):
    THIS_USER_IS_NOT_IN_YOUR_ORGANIZATION = 'This user is not in your organization'

class GetUserAvailabilitySchedules403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetUserAvailabilitySchedules403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[GetUserAvailabilitySchedules403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[GetUserAvailabilitySchedules403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetUserAvailabilitySchedulesErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetUserAvailabilitySchedulesErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[GetUserAvailabilitySchedulesErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GetUserAvailabilitySchedules200ApplicationJSON:
    r"""OK"""
    
    collection: list[shared_availabilityschedule.AvailabilitySchedule] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})  
    

@dataclasses.dataclass
class GetUserAvailabilitySchedulesResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[GetUserAvailabilitySchedulesErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    get_user_availability_schedules_200_application_json_object: Optional[GetUserAvailabilitySchedules200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    get_user_availability_schedules_403_application_json_object: Optional[GetUserAvailabilitySchedules403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from .delete_organizations_uuid_memberships import *
from .delete_users_user_uuid_webhooks_webhook_uuid import *
from .deleteinviteenoshow import *
from .get_event_types_uuid import *
from .get_organizations_org_uuid_invitations_uuid import *
from .get_organizations_uuid_invitations import *
from .get_organizations_uuid_memberships import *
from .get_routing_form_submissions import *
from .get_routing_form_submissions_uuid import *
from .get_routing_forms_uuid import *
from .get_scheduled_events_event_uuid_invitees_invitee_uuid import *
from .get_scheduled_events_uuid import *
from .get_users_user_uuid_webhooks_webhook_uuid import *
from .geteventtypeavailabletimes import *
from .getinviteenoshow import *
from .getinvitees import *
from .getuser import *
from .getuseravailabilityschedules import *
from .getuseravailabilityschedulesuuid import *
from .getuserbusytimes import *
from .list_activity_log import *
from .list_organization_memberships import *
from .list_routing_forms import *
from .list_webhooks import *
from .listeventtypes import *
from .listscheduledevents import *
from .me import *
from .post_data_compliance_deletion_events import *
from .post_data_compliance_deletion_invitees import *
from .post_organizations_uuid_invitations import *
from .post_scheduled_events_uuid_cancellation import *
from .post_scheduling_links import *
from .post_shares import *
from .post_users_uuid_webhooks import *
from .postinviteenoshow import *
from .revoke_users_organization_invitation import *

__all__ = ["DeleteInviteeNoShowErrorResponse","DeleteInviteeNoShowErrorResponseDetails","DeleteInviteeNoShowRequest","DeleteInviteeNoShowResponse","DeleteOrganizationsUUIDMembershipsErrorResponse","DeleteOrganizationsUUIDMembershipsErrorResponseDetails","DeleteOrganizationsUUIDMembershipsRequest","DeleteOrganizationsUUIDMembershipsResponse","DeleteUsersUserUUIDWebhooksWebhookUUIDErrorResponse","DeleteUsersUserUUIDWebhooksWebhookUUIDErrorResponseDetails","DeleteUsersUserUUIDWebhooksWebhookUUIDRequest","DeleteUsersUserUUIDWebhooksWebhookUUIDResponse","GetEventTypeAvailableTimes200ApplicationJSON","GetEventTypeAvailableTimesErrorResponse","GetEventTypeAvailableTimesErrorResponseDetails","GetEventTypeAvailableTimesRequest","GetEventTypeAvailableTimesResponse","GetEventTypesUUID200ApplicationJSON","GetEventTypesUUIDErrorResponse","GetEventTypesUUIDErrorResponseDetails","GetEventTypesUUIDRequest","GetEventTypesUUIDResponse","GetInviteeNoShow200ApplicationJSON","GetInviteeNoShowErrorResponse","GetInviteeNoShowErrorResponseDetails","GetInviteeNoShowRequest","GetInviteeNoShowResponse","GetInvitees200ApplicationJSON","GetInvitees403ApplicationJSON","GetInvitees403ApplicationJSONMessageEnum","GetInvitees403ApplicationJSONTitleEnum","GetInviteesErrorResponse","GetInviteesErrorResponseDetails","GetInviteesRequest","GetInviteesResponse","GetInviteesStatusEnum","GetOrganizationsOrgUUIDInvitationsUUID200ApplicationJSON","GetOrganizationsOrgUUIDInvitationsUUIDErrorResponse","GetOrganizationsOrgUUIDInvitationsUUIDErrorResponseDetails","GetOrganizationsOrgUUIDInvitationsUUIDRequest","GetOrganizationsOrgUUIDInvitationsUUIDResponse","GetOrganizationsUUIDInvitations200ApplicationJSON","GetOrganizationsUUIDInvitationsErrorResponse","GetOrganizationsUUIDInvitationsErrorResponseDetails","GetOrganizationsUUIDInvitationsRequest","GetOrganizationsUUIDInvitationsResponse","GetOrganizationsUUIDInvitationsStatusEnum","GetOrganizationsUUIDMemberships200ApplicationJSON","GetOrganizationsUUIDMembershipsErrorResponse","GetOrganizationsUUIDMembershipsErrorResponseDetails","GetOrganizationsUUIDMembershipsRequest","GetOrganizationsUUIDMembershipsResponse","GetRoutingFormSubmissions200ApplicationJSON","GetRoutingFormSubmissionsErrorResponse","GetRoutingFormSubmissionsErrorResponseDetails","GetRoutingFormSubmissionsRequest","GetRoutingFormSubmissionsResponse","GetRoutingFormSubmissionsUUID200ApplicationJSON","GetRoutingFormSubmissionsUUIDErrorResponse","GetRoutingFormSubmissionsUUIDErrorResponseDetails","GetRoutingFormSubmissionsUUIDRequest","GetRoutingFormSubmissionsUUIDResponse","GetRoutingFormsUUID200ApplicationJSON","GetRoutingFormsUUIDErrorResponse","GetRoutingFormsUUIDErrorResponseDetails","GetRoutingFormsUUIDRequest","GetRoutingFormsUUIDResponse","GetScheduledEventsEventUUIDInviteesInviteeUUID200ApplicationJSON","GetScheduledEventsEventUUIDInviteesInviteeUUIDErrorResponse","GetScheduledEventsEventUUIDInviteesInviteeUUIDErrorResponseDetails","GetScheduledEventsEventUUIDInviteesInviteeUUIDRequest","GetScheduledEventsEventUUIDInviteesInviteeUUIDResponse","GetScheduledEventsUUID200ApplicationJSON","GetScheduledEventsUUID403ApplicationJSON","GetScheduledEventsUUID403ApplicationJSONMessageEnum","GetScheduledEventsUUID403ApplicationJSONTitleEnum","GetScheduledEventsUUIDErrorResponse","GetScheduledEventsUUIDErrorResponseDetails","GetScheduledEventsUUIDRequest","GetScheduledEventsUUIDResponse","GetUser200ApplicationJSON","GetUserAvailabilitySchedules200ApplicationJSON","GetUserAvailabilitySchedules403ApplicationJSON","GetUserAvailabilitySchedules403ApplicationJSONMessageEnum","GetUserAvailabilitySchedules403ApplicationJSONTitleEnum","GetUserAvailabilitySchedulesErrorResponse","GetUserAvailabilitySchedulesErrorResponseDetails","GetUserAvailabilitySchedulesRequest","GetUserAvailabilitySchedulesResponse","GetUserAvailabilitySchedulesUUID200ApplicationJSON","GetUserAvailabilitySchedulesUUID403ApplicationJSON","GetUserAvailabilitySchedulesUUID403ApplicationJSONMessageEnum","GetUserAvailabilitySchedulesUUID403ApplicationJSONTitleEnum","GetUserAvailabilitySchedulesUUIDErrorResponse","GetUserAvailabilitySchedulesUUIDErrorResponseDetails","GetUserAvailabilitySchedulesUUIDRequest","GetUserAvailabilitySchedulesUUIDResponse","GetUserBusyTimes200ApplicationJSON","GetUserBusyTimes403ApplicationJSON","GetUserBusyTimes403ApplicationJSONMessageEnum","GetUserBusyTimes403ApplicationJSONTitleEnum","GetUserBusyTimesErrorResponse","GetUserBusyTimesErrorResponseDetails","GetUserBusyTimesRequest","GetUserBusyTimesResponse","GetUserErrorResponse","GetUserErrorResponseDetails","GetUserRequest","GetUserResponse","GetUsersUserUUIDWebhooksWebhookUUID200ApplicationJSON","GetUsersUserUUIDWebhooksWebhookUUIDErrorResponse","GetUsersUserUUIDWebhooksWebhookUUIDErrorResponseDetails","GetUsersUserUUIDWebhooksWebhookUUIDRequest","GetUsersUserUUIDWebhooksWebhookUUIDResponse","ListActivityLog200ApplicationJSON","ListActivityLog403ApplicationJSON","ListActivityLog403ApplicationJSONMessageEnum","ListActivityLog403ApplicationJSONTitleEnum","ListActivityLogErrorResponse","ListActivityLogErrorResponseDetails","ListActivityLogRequest","ListActivityLogResponse","ListActivityLogSortEnum","ListEventTypes200ApplicationJSON","ListEventTypes403ApplicationJSON","ListEventTypes403ApplicationJSONMessageEnum","ListEventTypes403ApplicationJSONTitleEnum","ListEventTypesErrorResponse","ListEventTypesErrorResponseDetails","ListEventTypesRequest","ListEventTypesResponse","ListOrganizationMemberships200ApplicationJSON","ListOrganizationMembershipsErrorResponse","ListOrganizationMembershipsErrorResponseDetails","ListOrganizationMembershipsRequest","ListOrganizationMembershipsResponse","ListRoutingForms200ApplicationJSON","ListRoutingFormsErrorResponse","ListRoutingFormsErrorResponseDetails","ListRoutingFormsRequest","ListRoutingFormsResponse","ListScheduledEvents403ApplicationJSON","ListScheduledEvents403ApplicationJSONMessageEnum","ListScheduledEvents403ApplicationJSONTitleEnum","ListScheduledEventsErrorResponse","ListScheduledEventsErrorResponseDetails","ListScheduledEventsRequest","ListScheduledEventsResponse","ListScheduledEventsStatusEnum","ListWebhooks200ApplicationJSON","ListWebhooks403ApplicationJSON","ListWebhooks403ApplicationJSONMessageEnum","ListWebhooks403ApplicationJSONTitleEnum","ListWebhooksErrorResponse","ListWebhooksErrorResponseDetails","ListWebhooksRequest","ListWebhooksResponse","ListWebhooksScopeEnum","Me200ApplicationJSON","MeErrorResponse","MeErrorResponseDetails","MeResponse","PostDataComplianceDeletionEventsErrorResponse","PostDataComplianceDeletionEventsErrorResponseDetails","PostDataComplianceDeletionEventsRequestBody","PostDataComplianceDeletionEventsResponse","PostDataComplianceDeletionInviteesErrorResponse","PostDataComplianceDeletionInviteesErrorResponseDetails","PostDataComplianceDeletionInviteesRequestBody","PostDataComplianceDeletionInviteesResponse","PostInviteeNoShow201ApplicationJSON","PostInviteeNoShowErrorResponse","PostInviteeNoShowErrorResponseDetails","PostInviteeNoShowRequestBody","PostInviteeNoShowResponse","PostOrganizationsUUIDInvitations201ApplicationJSON","PostOrganizationsUUIDInvitations403ApplicationJSON","PostOrganizationsUUIDInvitations403ApplicationJSONMessageEnum","PostOrganizationsUUIDInvitations403ApplicationJSONTitleEnum","PostOrganizationsUUIDInvitationsErrorResponse","PostOrganizationsUUIDInvitationsErrorResponseDetails","PostOrganizationsUUIDInvitationsRequest","PostOrganizationsUUIDInvitationsRequestBody","PostOrganizationsUUIDInvitationsResponse","PostScheduledEventsUUIDCancellation201ApplicationJSON","PostScheduledEventsUUIDCancellation403ApplicationJSON","PostScheduledEventsUUIDCancellation403ApplicationJSONMessageEnum","PostScheduledEventsUUIDCancellation403ApplicationJSONTitleEnum","PostScheduledEventsUUIDCancellationApplicationJSON","PostScheduledEventsUUIDCancellationErrorResponse","PostScheduledEventsUUIDCancellationErrorResponseDetails","PostScheduledEventsUUIDCancellationRequest","PostScheduledEventsUUIDCancellationResponse","PostSchedulingLinks201ApplicationJSON","PostSchedulingLinks201ApplicationJSONResource","PostSchedulingLinks201ApplicationJSONResourceOwnerTypeEnum","PostSchedulingLinksErrorResponse","PostSchedulingLinksErrorResponseDetails","PostSchedulingLinksRequestBody","PostSchedulingLinksRequestBodyMaxEventCountEnum","PostSchedulingLinksRequestBodyOwnerTypeEnum","PostSchedulingLinksResponse","PostShares201ApplicationJSON","PostSharesErrorResponse","PostSharesErrorResponseDetails","PostSharesRequestBody","PostSharesRequestBodyAvailabilityRule","PostSharesRequestBodyAvailabilityRuleRules","PostSharesRequestBodyAvailabilityRuleRulesIntervals","PostSharesRequestBodyAvailabilityRuleRulesTypeEnum","PostSharesRequestBodyAvailabilityRuleRulesWdayEnum","PostSharesRequestBodyLocationConfigurations","PostSharesRequestBodyLocationConfigurationsKindEnum","PostSharesRequestBodyPeriodTypeEnum","PostSharesResponse","PostUsersUUIDWebhooks201ApplicationJSON","PostUsersUUIDWebhooks403ApplicationJSON","PostUsersUUIDWebhooks403ApplicationJSONMessageEnum","PostUsersUUIDWebhooks403ApplicationJSONTitleEnum","PostUsersUUIDWebhooksErrorResponse","PostUsersUUIDWebhooksErrorResponseDetails","PostUsersUUIDWebhooksRequestBody","PostUsersUUIDWebhooksRequestBodyEventsEnum","PostUsersUUIDWebhooksRequestBodyScopeEnum","PostUsersUUIDWebhooksResponse","RevokeUsersOrganizationInvitation403ApplicationJSON","RevokeUsersOrganizationInvitation403ApplicationJSONMessageEnum","RevokeUsersOrganizationInvitation403ApplicationJSONTitleEnum","RevokeUsersOrganizationInvitationErrorResponse","RevokeUsersOrganizationInvitationErrorResponseDetails","RevokeUsersOrganizationInvitationRequest","RevokeUsersOrganizationInvitationResponse"]



"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class CancellationCancelerTypeEnum(str, Enum):
    HOST = 'host'
    INVITEE = 'invitee'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Cancellation:
    r"""Provides data pertaining to the cancellation of the Event"""
    
    canceled_by: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('canceled_by') }})
    r"""Name of the person whom canceled"""  
    canceler_type: CancellationCancelerTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('canceler_type') }})  
    reason: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('reason') }})
    r"""Reason that the cancellation occurred"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import pagination as shared_pagination
from ..shared import webhooksubscription as shared_webhooksubscription
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional

class ListWebhooksScopeEnum(str, Enum):
    r"""Filter the list by organization or user"""
    ORGANIZATION = 'organization'
    USER = 'user'


@dataclasses.dataclass
class ListWebhooksRequest:
    
    organization: str = dataclasses.field(metadata={'query_param': { 'field_name': 'organization', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by organization"""  
    scope: ListWebhooksScopeEnum = dataclasses.field(metadata={'query_param': { 'field_name': 'scope', 'style': 'form', 'explode': True }})
    r"""Filter the list by organization or user"""  
    count: Optional[float] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'count', 'style': 'form', 'explode': True }})
    r"""The number of rows to return"""  
    page_token: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'page_token', 'style': 'form', 'explode': True }})
    r"""The token to pass to get the next or previous portion of the collection"""  
    sort: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'sort', 'style': 'form', 'explode': True }})
    r"""Order results by the specified field and direction. Accepts comma-separated list of {field}:{direction} values.
    Supported fields are: created_at.
    Sort direction is specified as: asc, desc.
    """  
    user: Optional[str] = dataclasses.field(default=None, metadata={'query_param': { 'field_name': 'user', 'style': 'form', 'explode': True }})
    r"""Indicates if the results should be filtered by user. This parameter is only required if the `scope` parameter is set to `user`."""  
    
class ListWebhooks403ApplicationJSONMessageEnum(str, Enum):
    YOU_DO_NOT_HAVE_PERMISSION = 'You do not have permission'
    YOU_DO_NOT_HAVE_PERMISSION_TO_ACCESS_THIS_RESOURCE_ = 'You do not have permission to access this resource.'
    UNAUTHORIZED = 'Unauthorized'

class ListWebhooks403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListWebhooks403ApplicationJSON:
    r"""Permission Denied"""
    
    message: Optional[ListWebhooks403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[ListWebhooks403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListWebhooksErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListWebhooksErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[ListWebhooksErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ListWebhooks200ApplicationJSON:
    r"""OK"""
    
    collection: list[shared_webhooksubscription.WebhookSubscription] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})  
    pagination: shared_pagination.Pagination = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination') }})  
    

@dataclasses.dataclass
class ListWebhooksResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[ListWebhooksErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    list_webhooks_200_application_json_object: Optional[ListWebhooks200ApplicationJSON] = dataclasses.field(default=None)
    r"""OK"""  
    list_webhooks_403_application_json_object: Optional[ListWebhooks403ApplicationJSON] = dataclasses.field(default=None)
    r"""Permission Denied"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import dateutil.parser
from ..shared import actor as shared_actor
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from datetime import datetime
from marshmallow import fields
from typing import Any, Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Entry:
    r"""Object for a created activity log record"""
    
    action: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('action') }})  
    details: dict[str, Any] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details') }})  
    fully_qualified_name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('fully_qualified_name') }})  
    namespace: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('namespace') }})  
    occurred_at: datetime = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('occurred_at'), 'encoder': utils.datetimeisoformat(False), 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
    r"""The date and time of the entry (format: \\"2020-01-02T03:04:05.678Z\\")."""  
    organization: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('organization') }})  
    uri: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uri') }})  
    actor: Optional[shared_actor.Actor] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('actor'), 'exclude': lambda f: f is None }})
    r"""The Calendly actor that took the action creating the activity log entry
    
    Specific actors:
    
    <details>
    <summary>Calendly System</summary>
    
    Used when an action is performed by the Calendly system and not triggered directly by a user interaction.
    
    Example:
    ```json
    {
        \"display_name\": \"Calendly System\",
        \"type\": \"System\"
    }
    ```
    
    </details>
    
    <br />
    
    <details>
    <summary>Calendly Support</summary>
    Used when an action is performed by Calendly support.
    
    Example:
    ```json
    {
      \"display_name\": \"Calendly Support\",
      \"organization\": {
        \"uri\": \"https://api.calendly.com/organizations/AAAAAAAAAAAAAAAA\"
      },
      \"type\": \"User\",
      \"uri\": \"https://api.calendly.com/users/AAAAAAAAAAAAAAAA\"
    }
    ```
    </details>
    """  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GotoMeetingConferenceData:
    r"""The conference metadata supplied by GoToMeeting"""
    
    conference_call_info: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('conferenceCallInfo'), 'exclude': lambda f: f is None }})  
    unique_meeting_id: Optional[float] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('uniqueMeetingId'), 'exclude': lambda f: f is None }})
    r"""Canonical reference (unique identifier) for the GoToMeeting conference"""  
    
class GotoMeetingConferenceStatusEnum(str, Enum):
    r"""Indicates the current status of the GoToMeeting conference"""
    INITIATED = 'initiated'
    PROCESSING = 'processing'
    PUSHED = 'pushed'
    FAILED = 'failed'

class GotoMeetingConferenceTypeEnum(str, Enum):
    r"""The event location is a GoToMeeting conference"""
    GOTOMEETING = 'gotomeeting'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class GotoMeetingConference:
    r"""Details about an Event that will take place using a GotoMeeting conference"""
    
    data: GotoMeetingConferenceData = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('data') }})
    r"""The conference metadata supplied by GoToMeeting"""  
    join_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('join_url') }})
    r"""GoToMeeting conference meeting url"""  
    status: GotoMeetingConferenceStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates the current status of the GoToMeeting conference"""  
    type: GotoMeetingConferenceTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location is a GoToMeeting conference"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum

class EventTypeCustomQuestionTypeEnum(str, Enum):
    r"""The type of response that the invitee provides to the custom question; can be one or multiple lines of text, a phone number, or single- or multiple-select."""
    STRING = 'string'
    TEXT = 'text'
    PHONE_NUMBER = 'phone_number'
    SINGLE_SELECT = 'single_select'
    MULTI_SELECT = 'multi_select'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class EventTypeCustomQuestion:
    
    answer_choices: list[str] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('answer_choices') }})
    r"""The invitee’s option(s) for single_select or multi_select type of responses."""  
    enabled: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('enabled') }})
    r"""true if the question created by the host is turned ON and visible on the event booking page; false if turned OFF and invisible on the event booking page."""  
    include_other: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('include_other') }})
    r"""true if the custom question lets invitees record a written response in addition to single-select or multiple-select type of responses; false if it doesn’t."""  
    name: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('name') }})
    r"""The custom question that the host created for the event type."""  
    position: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('position') }})
    r"""The numerical position of the question on the event booking page after the name and email address fields."""  
    required: bool = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('required') }})
    r"""true if a response to the question created by the host is required for invitees to book the event type; false if not required."""  
    type: EventTypeCustomQuestionTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The type of response that the invitee provides to the custom question; can be one or multiple lines of text, a phone number, or single- or multiple-select."""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class Pagination:
    
    count: float = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('count') }})
    r"""The number of rows to return"""  
    next_page: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('next_page') }})
    r"""URI to return the next page of an ordered list (\\"null\\" indicates no additional results are available)"""  
    next_page_token: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('next_page_token') }})
    r"""Token to return the next page of an ordered list (\\"null\\" indicates no additional results are available)"""  
    previous_page: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('previous_page') }})
    r"""URI to return the previous page of an ordered list (\\"null\\" indicates no additional results are available)"""  
    previous_page_token: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('previous_page_token') }})
    r"""Token to return the previous page of an ordered list (\\"null\\" indicates no additional results are available)"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

import requests as requests_http
from . import utils
from calendly.models import operations
from typing import Optional

class EventTypes:
    _client: requests_http.Session
    _security_client: requests_http.Session
    _server_url: str
    _language: str
    _sdk_version: str
    _gen_version: str

    def __init__(self, client: requests_http.Session, security_client: requests_http.Session, server_url: str, language: str, sdk_version: str, gen_version: str) -> None:
        self._client = client
        self._security_client = security_client
        self._server_url = server_url
        self._language = language
        self._sdk_version = sdk_version
        self._gen_version = gen_version
        
    def get(self, request: operations.GetEventTypesUUIDRequest) -> operations.GetEventTypesUUIDResponse:
        r"""Get Event Type
        Returns information about a specified Event Type.
        """
        base_url = self._server_url
        
        url = utils.generate_url(operations.GetEventTypesUUIDRequest, base_url, '/event_types/{uuid}', request)
        
        
        client = self._security_client
        
        http_res = client.request('GET', url)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetEventTypesUUIDResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetEventTypesUUID200ApplicationJSON])
                res.get_event_types_uuid_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetEventTypesUUIDErrorResponse])
                res.error_response = out

        return res

    def get_available_times(self, request: operations.GetEventTypeAvailableTimesRequest) -> operations.GetEventTypeAvailableTimesResponse:
        r"""List Event Type Available Times
        Returns a list of available times for an event type within a specified date range.
        
        Date range can be no greater than 1 week (7 days).
        
        **NOTE:**
        * This endpoint does not support traditional keyset pagination.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/event_type_available_times'
        
        query_params = utils.get_query_params(operations.GetEventTypeAvailableTimesRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.GetEventTypeAvailableTimesResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetEventTypeAvailableTimes200ApplicationJSON])
                res.get_event_type_available_times_200_application_json_object = out
        elif http_res.status_code in [400, 401, 403, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.GetEventTypeAvailableTimesErrorResponse])
                res.error_response = out

        return res

    def list(self, request: operations.ListEventTypesRequest) -> operations.ListEventTypesResponse:
        r"""List User's Event Types
        Returns all Event Types associated with a specified User. Use:
        
        * `organization` to look up all Event Types that belong to the organization
        
        * `user` to look up a user's Event Types in an organization
        
        Either `organization` or `user` are required query params when using this endpoint.
        """
        base_url = self._server_url
        
        url = base_url.removesuffix('/') + '/event_types'
        
        query_params = utils.get_query_params(operations.ListEventTypesRequest, request)
        
        client = self._security_client
        
        http_res = client.request('GET', url, params=query_params)
        content_type = http_res.headers.get('Content-Type')

        res = operations.ListEventTypesResponse(status_code=http_res.status_code, content_type=content_type, raw_response=http_res)
        
        if http_res.status_code == 200:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListEventTypes200ApplicationJSON])
                res.list_event_types_200_application_json_object = out
        elif http_res.status_code in [400, 401, 404, 500]:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListEventTypesErrorResponse])
                res.error_response = out
        elif http_res.status_code == 403:
            if utils.match_content_type(content_type, 'application/json'):
                out = utils.unmarshal_json(http_res.text, Optional[operations.ListEventTypes403ApplicationJSON])
                res.list_event_types_403_application_json_object = out

        return res

    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from ..shared import event as shared_event
from ..shared import pagination as shared_pagination
from calendly import utils
from dataclasses_json import Undefined, dataclass_json


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ScheduledEventsResponse:
    r"""Service response"""
    
    collection: list[shared_event.Event] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('collection') }})
    r"""The set of scheduled events matching the criteria"""  
    pagination: shared_pagination.Pagination = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('pagination') }})  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ZoomConferenceDataExtra:
    
    intl_numbers_url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('intl_numbers_url'), 'exclude': lambda f: f is None }})
    r"""Zoom International Dial-in Numbers URL"""  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ZoomConferenceDataSettingsGlobalDialInNumbers:
    
    city: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('city'), 'exclude': lambda f: f is None }})  
    country: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('country'), 'exclude': lambda f: f is None }})
    r"""Country code"""  
    country_name: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('country_name'), 'exclude': lambda f: f is None }})  
    number: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('number'), 'exclude': lambda f: f is None }})
    r"""Phone number"""  
    type: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ZoomConferenceDataSettings:
    
    global_dial_in_numbers: Optional[list[ZoomConferenceDataSettingsGlobalDialInNumbers]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('global_dial_in_numbers'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ZoomConferenceData:
    r"""The conference metadata supplied by Zoom"""
    
    extra: Optional[ZoomConferenceDataExtra] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('extra'), 'exclude': lambda f: f is None }})  
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
    r"""The conference ID provided by Zoom"""  
    password: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('password'), 'exclude': lambda f: f is None }})
    r"""Zoom meeting password"""  
    settings: Optional[ZoomConferenceDataSettings] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('settings'), 'exclude': lambda f: f is None }})  
    
class ZoomConferenceStatusEnum(str, Enum):
    r"""Indicates the current status of the Zoom conference"""
    INITIATED = 'initiated'
    PROCESSING = 'processing'
    PUSHED = 'pushed'
    FAILED = 'failed'

class ZoomConferenceTypeEnum(str, Enum):
    r"""The event location is a Zoom conference"""
    ZOOM_CONFERENCE = 'zoom_conference'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class ZoomConference:
    r"""Meeting will take place in a Zoom conference"""
    
    data: ZoomConferenceData = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('data') }})
    r"""The conference metadata supplied by Zoom"""  
    join_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('join_url') }})
    r"""Zoom meeting url"""  
    status: ZoomConferenceStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates the current status of the Zoom conference"""  
    type: ZoomConferenceTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location is a Zoom conference"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
import requests as requests_http
from ..shared import cancellation as shared_cancellation
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostScheduledEventsUUIDCancellationApplicationJSON:
    r"""Optional cancellation reason."""
    
    reason: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('reason'), 'exclude': lambda f: f is None }})
    r"""Reason for cancellation"""  
    

@dataclasses.dataclass
class PostScheduledEventsUUIDCancellationRequest:
    
    uuid: str = dataclasses.field(metadata={'path_param': { 'field_name': 'uuid', 'style': 'simple', 'explode': False }})
    r"""The event's unique indentifier"""  
    request_body: Optional[PostScheduledEventsUUIDCancellationApplicationJSON] = dataclasses.field(default=None, metadata={'request': { 'media_type': 'application/json' }})
    r"""Optional cancellation reason."""  
    
class PostScheduledEventsUUIDCancellation403ApplicationJSONMessageEnum(str, Enum):
    YOU_ARE_NOT_ALLOWED_TO_CANCEL_THIS_EVENT = 'You are not allowed to cancel this event'
    EVENT_IN_THE_PAST = 'Event in the past'
    EVENT_IS_ALREADY_CANCELED = 'Event is already canceled'

class PostScheduledEventsUUIDCancellation403ApplicationJSONTitleEnum(str, Enum):
    PERMISSION_DENIED = 'Permission Denied'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostScheduledEventsUUIDCancellation403ApplicationJSON:
    r"""Caller not authorized to perform this action"""
    
    message: Optional[PostScheduledEventsUUIDCancellation403ApplicationJSONMessageEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message'), 'exclude': lambda f: f is None }})  
    title: Optional[PostScheduledEventsUUIDCancellation403ApplicationJSONTitleEnum] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostScheduledEventsUUIDCancellationErrorResponseDetails:
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    parameter: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('parameter'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostScheduledEventsUUIDCancellationErrorResponse:
    r"""Error Object"""
    
    message: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('message') }})  
    title: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('title') }})  
    details: Optional[list[PostScheduledEventsUUIDCancellationErrorResponseDetails]] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('details'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class PostScheduledEventsUUIDCancellation201ApplicationJSON:
    r"""Created"""
    
    resource: shared_cancellation.Cancellation = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('resource') }})
    r"""Provides data pertaining to the cancellation of the Event"""  
    

@dataclasses.dataclass
class PostScheduledEventsUUIDCancellationResponse:
    
    content_type: str = dataclasses.field()  
    status_code: int = dataclasses.field()  
    error_response: Optional[PostScheduledEventsUUIDCancellationErrorResponse] = dataclasses.field(default=None)
    r"""Request is not valid"""  
    post_scheduled_events_uuid_cancellation_201_application_json_object: Optional[PostScheduledEventsUUIDCancellation201ApplicationJSON] = dataclasses.field(default=None)
    r"""Created"""  
    post_scheduled_events_uuid_cancellation_403_application_json_object: Optional[PostScheduledEventsUUIDCancellation403ApplicationJSON] = dataclasses.field(default=None)
    r"""Caller not authorized to perform this action"""  
    raw_response: Optional[requests_http.Response] = dataclasses.field(default=None)  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class WebExConferenceDataTelephonyCallInNumbers:
    
    call_in_number: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('callInNumber') }})  
    label: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('label') }})  
    toll_type: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tollType') }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class WebExConferenceDataTelephony:
    
    call_in_numbers: list[WebExConferenceDataTelephonyCallInNumbers] = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('callInNumbers') }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class WebExConferenceData:
    r"""The conference metadata supplied by GoToMeeting"""
    
    id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id') }})
    r"""Canonical reference (unique identifier) for the WebEx conference"""  
    password: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('password') }})  
    telephony: WebExConferenceDataTelephony = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('telephony') }})  
    
class WebExConferenceStatusEnum(str, Enum):
    r"""Indicates the current status of the WebEx conference"""
    INITIATED = 'initiated'
    PROCESSING = 'processing'
    PUSHED = 'pushed'
    FAILED = 'failed'

class WebExConferenceTypeEnum(str, Enum):
    r"""The event location is a WebEx conference"""
    WEBEX_CONFERENCE = 'webex_conference'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class WebExConference:
    r"""Details about an Event that will take place using a WebEx conference"""
    
    data: WebExConferenceData = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('data') }})
    r"""The conference metadata supplied by GoToMeeting"""  
    join_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('join_url') }})
    r"""WebEx conference meeting url"""  
    status: WebExConferenceStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates the current status of the WebEx conference"""  
    type: WebExConferenceTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location is a WebEx conference"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json
from enum import Enum
from typing import Optional


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class MicrosoftTeamsConferenceDataAudioConferencing:
    
    conference_id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('conferenceId'), 'exclude': lambda f: f is None }})  
    dialin_url: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('dialinUrl'), 'exclude': lambda f: f is None }})  
    toll_number: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('tollNumber'), 'exclude': lambda f: f is None }})  
    

@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class MicrosoftTeamsConferenceData:
    r"""The conference metadata supplied by Microsoft Teams"""
    
    audio_conferencing: Optional[MicrosoftTeamsConferenceDataAudioConferencing] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('audioConferencing'), 'exclude': lambda f: f is None }})  
    id: Optional[str] = dataclasses.field(default=None, metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('id'), 'exclude': lambda f: f is None }})
    r"""The conference ID provided by Microsoft Teams"""  
    
class MicrosoftTeamsConferenceStatusEnum(str, Enum):
    r"""Indicates the current status of the Microsoft Teams conference"""
    INITIATED = 'initiated'
    PROCESSING = 'processing'
    PUSHED = 'pushed'
    FAILED = 'failed'

class MicrosoftTeamsConferenceTypeEnum(str, Enum):
    r"""The event location is a Zoom conference"""
    MICROSOFT_TEAMS_CONFERENCE = 'microsoft_teams_conference'


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class MicrosoftTeamsConference:
    r"""Meeting will take place in a Microsoft Teams conference"""
    
    data: MicrosoftTeamsConferenceData = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('data') }})
    r"""The conference metadata supplied by Microsoft Teams"""  
    join_url: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('join_url') }})
    r"""Microsoft Teams meeting url"""  
    status: MicrosoftTeamsConferenceStatusEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('status') }})
    r"""Indicates the current status of the Microsoft Teams conference"""  
    type: MicrosoftTeamsConferenceTypeEnum = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('type') }})
    r"""The event location is a Zoom conference"""  
    


"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
import dataclasses
from calendly import utils
from dataclasses_json import Undefined, dataclass_json


@dataclass_json(undefined=Undefined.EXCLUDE)
@dataclasses.dataclass
class InviteeTracking:
    r"""The UTM and Salesforce tracking parameters associated with an Invitee"""
    
    salesforce_uuid: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('salesforce_uuid') }})
    r"""The Salesforce record unique identifier"""  
    utm_campaign: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('utm_campaign') }})
    r"""The UTM parameter used to track a campaign"""  
    utm_content: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('utm_content') }})
    r"""UTM content tracking parameter"""  
    utm_medium: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('utm_medium') }})
    r"""The UTM parameter that identifies the type of input (e.g. Cost Per Click (CPC), social media, affiliate or QR code)"""  
    utm_source: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('utm_source') }})
    r"""The UTM parameter that identifies the source (platform where the traffic originates)"""  
    utm_term: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.get_field_name('utm_term') }})
    r"""The UTM parameter used to track keywords"""  
    